"""Модуль вспомогательных функций"""

from . import users
from . import groups
from . import departments

def check_request(req):
    """Функция проверки ответа запроса

    :param req: результат запроса
    :type req: dict
    """

    if 'code' in req and 'message' in req: return False

    return True

def get_id_group_by_label(sstr, token, orgID):
    """Функция преобразования label группы в id

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param sstr: строка поиска
    :type sstr: str
    :return: ID группы: {'id': int}
    :rtype: dict

    """

    grps = groups.show_groups(token, orgID)
    if check_request(grps):
        while grps['page'] <= grps['pages']:
            for group in grps['groups']:
                if group['label'] == sstr:
                    return {'id':group['id']}
            grps = groups.show_groups(token, orgID, page=grps['page']+1)
    else:
        return grps

def get_id_department_by_label(sstr, token, orgID):
    """Функция преобразования label подразделения в id

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param sstr: строка поиска
    :type sstr: str
    :return: ID подразделения: {'id': int}
    :rtype: dict

    """

    dep = departments.show_departments(token, orgID)

    if check_request(dep):
        while dep['page'] <= dep['pages']:
            for department in dep['departments']:
                if department['label'] == sstr:
                    return {'id':department['id']}
            dep = departments.show_departments(token, orgID, page=dep['page']+1)
    else:
        return dep

def get_id_user_by_nickname(sstr, token, orgID):
    """Функция преобразования nickname пользователя в id

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param sstr: строка поиска
    :type sstr: str
    :return: ID пользователя {'id': str}
    :rtype: dict

    """
     
    usrs = users.show_users(token, orgID)

    if check_request(usrs):
        while usrs['page'] <= usrs['pages']:
            for user in usrs['users']:
                if user['nickname'] == sstr:
                    return {'id':user['id']}
            usrs = users.show_users(token, orgID, page=usrs['page']+1)
    else:
        return usrs

def get_groups(token, orgID):
    """Функция вывода всех групп
    
    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :return: словарь групп
    :rtype: dict
    
    """

    lst_grp =[]

    grps = groups.show_groups(token, orgID)
    if check_request(grps):
        while grps['page'] <= grps['pages']:
            lst_grp += grps['groups']
            grps = groups.show_groups(token, orgID, page=grps['page']+1)
        return {"groups":lst_grp,"page":grps['page'],"pages":grps['pages'],"perPage":grps['perPage'],"total":grps['total']}
    else:
        return grps

def get_departments(token, orgID):
    """Функция вывода всех подразделений
    
    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :return: словарь подразделений
    :rtype: dict
    
    """

    lst_dep =[]

    deps = departments.show_departments(token, orgID)
    if check_request(deps):
        while deps['page'] <= deps['pages']:
            lst_dep += deps['departments']
            deps = departments.show_departmets(token, orgID, page=deps['page']+1)
        return {"departments":lst_dep,"page":deps['page'],"pages":deps['pages'],"perPage":deps['perPage'],"total":deps['total']}
    else:
        return deps

def get_users(token, orgID):
    """Функция вывода всех пользователей
    
    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :return: словарь пользователей
    :rtype: dict
    
    """

    lst_usr =[]

    usrs = users.show_users(token, orgID)
    if check_request(usrs):
        while usrs['page'] <= usrs['pages']:
            lst_usr += users['users']
            usrs = users.show_users(token, orgID, page=usrs['page']+1)
        return {"users":lst_usr,"page":usrs['page'],"pages":usrs['pages'],"perPage":usrs['perPage'],"total":usrs['total']}
    else:
        return usrs

def get_domains(token, orgID):
    """Функция вывода всех доменов
    
    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :return: словарь доменов
    :rtype: dict
    
    """

    lst_dom =[]

    doms = domains.show_domains(token, orgID)
    if check_request(doms):
        while doms['page'] <= doms['pages']:
            lst_dom += doms['domains']
            usrs = domains.show_users(token, orgID, page=usrs['page']+1)
        return {"domains":lst_dom,"page":doms['page'],"pages":doms['pages'],"perPage":doms['perPage'],"total":doms['total']}
    else:
        return doms


"""Модуль функций для управления DNS записями домена

.. note::
    **Разрешения работы с DNS:**

    **directory:manage_dns** — управление DNS (чтение и запись).


"""

from jreq.jreq import safe_request
import json

def show_dns (token, orgID, domain, page=1, perPage=50):
    """Функция позволяет получить все DNS-записи, которые были установлены для домена

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param domain: :term:`Полное доменное имя`
    :type domain: str
    :param page: Номер страницы ответа. Значение по умолчанию — 1
    :type page: int
    :param perPage: Количество записей на одной странице ответа. Значение по умолчанию — 50
    :type perPage: int
    :return: :numref:`результат запроса %s <Результат запроса show_dns>`
    :rtype: dict

    .. code-block:: python
        :caption: Результат запроса show_dns
        :name: Результат запроса show_dns

        {
            "page": int,
            "pages": int,
            "perPage": int,
            "records": [
                {
                    "address": str,
                    "exchange": str,
                    "flag": int,
                    "name": str,
                    "port": int,
                    "preference": int,
                    "priority": int,
                    "recordId": int,
                    "tag": str,
                    "target": str,
                    "text": str,
                    "ttl": int,
                    "type": str,
                    "value": str,
                    "weight": int
                }
            ],
            "total": int
        }

    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/domains/{domain}/dns?page={page}&perPage={perPage}'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('get',url, headers)

def delete_dns (token, orgID, domain, recordID):
    """Функция позволяет удалить DNS-запись

    .. danger::
        **Данная операция необратима, восстановить данные будет невозможно!**

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param domain: :term:`Полное доменное имя`
    :type domain: str
    :param recordID: :term:`ID записи`
    :type recordID: int
    :return: результат запроса
    :rtype: dict
    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/domains/{domain}/dns/{recordID}'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('delete',url, headers)

def add_dns (token, orgID, domain, body):
    """Функция позволяет добавить DNS-запись

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param domain: :term:`Полное доменное имя`
    :type domain: str
    :param body: :numref:`тело запроса %s <Тело запроса add_dns>`
    :type body: dict
    :return: :numref:`результат запроса %s <Результат запроса add_dns>`
    :rtype: dict

    .. code-block:: python
        :caption: Тело запроса add_dns
        :name: Тело запроса add_dns

        {
            "address": str,
            "exchange": str,
            "flag": int,
            "name": str,
            "port": int,
            "preference": int,
            "priority": int,
            "tag": str,
            "target": str,
            "text": str,
            "ttl": int,
            "type": str,
            "value": str,
            "weight": int
        }

    .. code-block:: python
        :caption: Результат запроса add_dns
        :name: Результат запроса add_dns

        {
            "address": str,
            "exchange": str,
            "flag": int,
            "name": str,
            "port": int,
            "preference": int,
            "priority": int,
            "tag": str,
            "target": str,
            "text": str,
            "ttl": int,
            "type": str,
            "value": str,
            "weight": int
        }

    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/domains/{domain}/dns'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('post',url, headers, json.dumps(body))

def edit_dns (token, orgID, domain, recordID, body):
    """Функция позволяет добавить DNS-запись

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param domain: :term:`Полное доменное имя`
    :type domain: str
    :param recordID: :term:`ID записи`
    :type recordID: int
    :param body: :numref:`тело запроса %s <Тело запроса edit_dns>`
    :type body: dict
    :return: :numref:`результат запроса %s <Результат запроса edit_dns>`
    :rtype: dict

    .. code-block:: python
        :caption: Тело запроса edit_dns
        :name: Тело запроса edit_dns

        {
            "address": str,
            "exchange": str,
            "name": str,
            "port": int,
            "preference": int,
            "priority": int,
            "target": str,
            "text": str,
            "ttl": int,
            "type": str,
            "weight": int
        }

    .. code-block:: python
        :caption: Результат запроса edit_dns
        :name: Результат запроса edit_dns

        {
            "address": str,
            "exchange": str,
            "flag": int,
            "name": str,
            "port": int,
            "preference": int,
            "priority": int,
            "tag": str,
            "target": str,
            "text": str,
            "ttl": int,
            "type": str,
            "value": str,
            "weight": int
        }
 
    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/domains/{domain}/dns/{recordID}'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('post',url, headers, json.dumps(body))


"""Модуль для управления аудит-логов.
"""

from jreq.jreq import safe_request
import json

def disk_log(token, orgID, pageSize=100, pageToken=None, beforeDate=None, afterDate=None, includeUids=None, excludeUids=None):
    """Функция возвращает список событий в аудит-логе Диска организации.

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param pageSize: Количество событий на странице
    :type pageSize: int
    :param pageToken: Токен постраничной навигации
    :type pageToken: str
    :param beforeDate: Верхняя граница периода выборки в формате ISO 8601
    :type beforeDate: str
    :param afterDate: Нижняя граница периода выборки в формате ISO 8601
    :type afterDate: str
    :param includeUids: Список пользователей, действия которых должны быть включены в список событий
    :type includeUids: str
    :param excludeUids: Список пользователей, действия которых должны быть исключены из списка событий
    :type excludeUids: str
    :return: :numref:`результат запроса %s <Результат запроса disk_log>`
    :rtype: dict

    .. code-block:: python
        :caption: Результат запроса disk_log
        :name: Результат запроса disk_log

        {
            "events": [
                {
                    "clientIp": str,
                    "date": str,
                    "eventType": str,
                    "lastModificationDate": str,
                    "orgId": int,
                    "ownerLogin": str,
                    "ownerName": str,
                    "ownerUid": str,
                    "path": str,
                    "requestId": str,
                    "resourceFileId": str,
                    "rights": str,
                    "size": str,
                    "uniqId": str,
                    "userLogin": str,
                    "userName": str,
                    "userUid": str
                }
            ],
            "nextPageToken": str
        }

    """

    url = f'https://api360.yandex.net/security/v1/org/{orgID}/audit_log/disk?pageSize={pageSize}'
    if pageToken: url += f'&pageToken={pageToken}'
    if beforeDate: url += f'&beforeDate={beforeDate}'
    if afterDate: url += f'&afterDate={afterDate}'
    if includeUids: url += f'&includeUids={includeUids}'
    if excludeUids: url += f'&excludeUids={excludeUids}'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}
	
    return safe_request('get', url, headers)

def mail_log(token, orgID, pageSize=100, pageToken=None, beforeDate=None, afterDate=None, includeUids=None, excludeUids=None, types=None):
    """Функция возвращает список событий в аудит-логе Почте организации.

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param pageSize: Количество событий на странице
    :type pageSize: int
    :param pageToken: Токен постраничной навигации
    :type pageToken: str
    :param beforeDate: Верхняя граница периода выборки в формате ISO 8601
    :type beforeDate: str
    :param afterDate: Нижняя граница периода выборки в формате ISO 8601
    :type afterDate: str
    :param includeUids: Список пользователей, действия которых должны быть включены в список событий
    :type includeUids: str
    :param excludeUids: Список пользователей, действия которых должны быть исключены из списка событий
    :type excludeUids: str
    :param types: Типы событий которые должны быть включены в список. По умолчанию включаются все события
    :type types: str
    :return: :numref:`результат запроса %s <Результат запроса mail_log>`
    :rtype: dict

    .. code-block:: python
        :caption: Результат запроса mail_log
        :name: Результат запроса mail_log

        {
            "events": [
                {
                    "bcc": str,
                    "cc": str,
                    "clientIp": str,
                    "date": str,
                    "destMid": str,
                    "eventType": str,
                    "folderName": str,
                    "folderType": str,
                    "from": str,
                    "labels": [
                        str
                    ],
                    "mid": str,
                    "msgId": str,
                    "orgId": int,
                    "requestId": str,
                    "source": str,
                    "subject": str,
                    "to": str,
                    "uniqId": str,
                    "userLogin": str,
                    "userName": str,
                    "userUid": str
                }
            ],
            "nextPageToken": str
        }

    """

    url = f'https://api360.yandex.net/security/v1/org/{orgID}/audit_log/mail?pageSize={pageSize}'
    if pageToken: url += f'&pageToken={pageToken}'
    if beforeDate: url += f'&beforeDate={beforeDate}'
    if afterDate: url += f'&afterDate={afterDate}'
    if includeUids: url += f'&includeUids={includeUids}'
    if excludeUids: url += f'&excludeUids={excludeUids}'
    if types: url += f'&types={types}'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}
	
    return safe_request('get', url, headers)


"""Модуль функций для работы с группами. Просмотр, создание, изменение и удаление.

.. note::
    **Права доступа для работы с группами:**

    **directory:read_groups** — просмотр;
    **directory:write_groups** — просмотр и изменение.


"""

from jreq.jreq import safe_request
import json

def add_group(token, orgID, body):
    """Функция создает новую группу.
    
    .. note::
        Пользователь, от имени которого выполняется запрос, не включается в состав группы

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param body: :numref:`Тело запроса %s <Тело запроса add_group>`
    :type body: dict
    :return: :numref:`результат запроса %s <Результат запроса add_group>`
    :rtype: dict

    .. code-block:: python
        :caption: Тело запроса add_group
        :name: Тело запроса add_group

        {
            "adminIds": [
                str
            ],
            "description": str,
            "externalId": str,
            "label": str,
            "members": [
                {
                    "id": str,
                    "type": str
                }
            ],
            "name": str
        }

    .. code-block:: python
        :caption: Результат запроса add_group
        :name: Результат запроса add_group

        {
            "adminIds": [
                str
            ],
            "aliases": [
                str
            ],
            "authorId": str,
            "createdAt": str,
            "description": str,
            "email": str,
            "externalId": str,
            "id": int,
            "label": str,
            "memberOf": [
                int
            ],
            "members": [
                {
                    "id": str,
                    "type": str
                }
            ],
            "membersCount": int,
            "name": str,
            "removed": bool,
            "type": str
        }

    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/groups'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}
    
    return safe_request('post', url, headers, json.dumps(body))

def update_group(token, orgID, groupID, body):
	"""Функция изменяет информацию о группе.
    
    .. note::
        Изменяются значения только тех параметров, которые были переданы в запросе.
	
    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param ID: ID группы
    :type ID: str
    :param body: :numref:`Тело запроса %s <Тело запроса update_group>`
    :type body: dict
    :return: :numref:`результат запроса %s <Результат запроса update_group>`
    :rtype: dict

    .. code-block:: python
        :caption: Тело запроса update_group
        :name: Тело запроса update_group

        {
            "adminIds": [
                str
            ],
            "description": str,
            "externalId": str,
            "label": str,
            "members": [
                {
                    "id": str,
                    "type": str
                }
            ],
            "name": str
        }

    .. code-block:: python
        :caption: Результат запроса update_group
        :name: Результат запроса update_group

        {
            "adminIds": [
                str
            ],
            "aliases": [
                str
            ],
            "authorId": str,
            "createdAt": str,
            "description": str,
            "email": str,
            "externalId": str,
            "id": int,
            "label": str,
            "memberOf": [
                int
            ],
            "members": [
                {
                    "id": str,
                    "type": str
                }
            ],
            "membersCount": int,
            "name": str,
            "removed": bool,
            "type": str
        }

	"""

	url = f'https://api360.yandex.net/directory/v1/org/{orgID}/groups/{groupID}'
	headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

	return safe_request('patch', url, headers, json.dumps(body))

def delete_group(token, orgID, groupID):
    """Функция удаляет группу.
    
    .. note::
        Участники, которые входили в группу, не удаляются

    .. danger::
        **Данная операция необратима, восстановить данные будет невозможно!**
    
    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param ID: ID группы
    :type ID: str
    :return: :numref:`результат запроса %s <Результат запроса delete_group>`
    :rtype: dict

    .. code-block:: python
        :caption: Результат запроса delete_group
        :name: Результат запроса delete_group

        {
            "id": int,
            "removed": bool
        }

    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/groups/{groupID}'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('delete', url, headers)

def add_member_group(token, orgID, groupID, body):
    """Функция добавляет участника в группу.
    
    .. note::
        Участником группы может быть сотрудник организации, отдельное подразделение или другая группа

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param ID: ID группы
    :type ID: str
    :param body: :numref:`Тело запроса %s <Тело запроса add_member_group>`
    :type body: dict
    :return: :numref:`результат запроса %s <Результат запроса add_member_group>`
    :rtype: dict

    .. code-block:: python
        :caption: Тело запроса add_member_group
        :name: Тело запроса add_member_group

        {
            "id": str,
            "type": str
        }

    .. code-block:: python
        :caption: Результат запроса add_member_group
        :name: Результат запроса add_member_group

        {
            "added": bool,
            "id": str,
            "type": str
        }

    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/groups/{groupID}/members'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('post', url, headers, json.dumps(body))

def delete_member_group(token, orgID, groupID, memberType, memberID):
    """Функция удаляет конкретного участника из группы: сотрудника организации, подразделение или вложенную группу

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param ID: ID группы
    :type ID: str
    :param userType: тип участника
    :type userTupe: str
    :param userID: ID участника
    :type userID: str
    :return: :numref:`результат запроса %s <Результат запроса delete_member_group>`
    :rtype: dict

    .. code-block:: python
        :caption: Результат запроса delete_member_group
        :name: Результат запроса delete_member_group

        {
            "deleted": bool,
            "id": str,
            "type": str
        }

    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/groups/{groupID}/members/{memberType}/{memberID}'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('delete', url, headers)

def delete_all_members_group(token, orgID, groupID):
    """Функция удаляет из группы всех участников

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param ID: ID группы
    :type ID: str
    :return: :numref:`результат запроса %s <Результат запроса delete_all_members_group>`
    :rtype: dict

    .. code-block:: python
        :caption: Результат запроса delete_all_members_group
        :name: Результат запроса delete_all_members_group

        {
            "departments": [
                {
                    "id": int,
                    "membersCount": int,
                    "name": str
                }
            ],
            "groups": [
                {
                    "id": int,
                    "membersCount": int,
                    "name": str
                }
            ],
            "users": [
                {
                    "avatarId": str,
                    "departmentId": int,
                    "email": str,
                    "gender": str,
                    "id": str,
                    "name": {
                        "first": str,
                        "last": str,
                        "middle": str
                    },
                    "nickname": str,
                    "position": str
                }
            ]
        }

    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/groups/{groupID}/members'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('delete', url, headers)

def show_group(token, orgID, groupID):
    """Функция возвращает информацию об одной группе
	
    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param ID: ID группы
    :type ID: str
    :return: :numref:`результат запроса %s <Результат запроса show_group>`
    :rtype: dict

    .. code-block:: python
        :caption: Результат запроса show_group
        :name: Результат запроса show_group

        {
            "adminIds": [
                str
            ],
            "aliases": [
                str
            ],
            "authorId": str,
            "createdAt": str,
            "description": str,
            "email": str,
            "externalId": str,
            "id": int,
            "label": str,
            "memberOf": [
                int
            ],
            "members": [
                {
                    "id": str,
                    "type": str
                }
            ],
            "membersCount": int,
            "name": str,
            "removed": bool,
            "type": str
        }

    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/groups/{groupID}'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}
    
    return safe_request('get', url, headers)

def show_members_group(token, orgID, groupID):
    """Функция возвращает список участников группы, таких как сотрудники, подразделения или другие группы
	
    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param ID: ID группы
    :type ID: str
    :return: :numref:`результат запроса %s <Результат запроса show_members_group>`
    :rtype: dict

    .. code-block:: python
        :caption: Результат запроса show_members_group
        :name: Результат запроса show_members_group

        {
            "departments": [
                {
                    "id": int,
                    "membersCount": int,
                    "name": str
                }
            ],
            "groups": [
                {
                    "id": int,
                    "membersCount": int,
                    "name": str
                }
            ],
            "users": [
                {
                    "avatarId": str,
                    "departmentId": int,
                    "email": str,
                    "gender": str,
                    "id": str,
                    "name": {
                        "first": str,
                        "last": str,
                        "middle": str
                    },
                    "nickname": str,
                    "position": str
                }
            ]
        }

    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/groups/{groupID}/members/'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}
    
    return safe_request('get', url, headers)

def show_groups(token, orgID, page=1,perPage=10):
    """Функция возвращает список групп с постраничной навигацией

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param page: Номер страницы ответа. Значение по умолчанию — 1
    :type page: int
    :param perPage: Количество групп на одной странице ответа. Значение по умолчанию — 10
    :type perPage: int
    :return: :numref:`результат запроса %s <Результат запроса show_groups>`
    :rtype: dict

    .. code-block:: python
        :caption: Результат запроса show_groups
        :name: Результат запроса show_groups

        {
            "groups": [
                {
                    "adminIds": [
                        str
                    ],
                    "aliases": [
                        str
                    ],
                    "authorId": str,
                    "createdAt": str,
                    "description": str,
                    "email": str,
                    "externalId": str,
                    "id": int,
                    "label": str,
                    "memberOf": [
                        int
                    ],
                    "members": [
                        {
                            "id": str,
                            "type": str
                        }
                    ],
                    "membersCount": int,
                    "name": str,
                    "removed": bool,
                    "type": str
                }
            ],
            "page": int,
            "pages": int,
            "perPage": int,
            "total": int
        }

    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/groups/?page={page}&perPage={perPage}'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}
	
    return safe_request('get', url, headers)

def update_admin_group(token, orgID, groupID, body):
	"""Функция назначает руководителей группы.
    
    .. warning::
        Руководителем группы может стать любой сотрудник организации. Изменяет сразу весь список руководителей
	
    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param ID: ID группы
    :type ID: str
    :param body: :numref:`Тело запроса %s <Тело запроса update_admin_group>`
    :type body: dict
    :return: :numref:`результат запроса %s <Результат запроса update_admin_group>`
    :rtype: dict

    .. code-block:: python
        :caption: Тело запроса update_admin_group
        :name: Тело запроса update_admin_group

        {
            "adminIds": [
                "str"
            ]
        }

    .. code-block:: python
        :caption: Результат запроса update_admin_group
        :name: Результат запроса update_admin_group

        {
            "adminIds": [
                str
            ],
            "aliases": [
                str
            ],
            "authorId": str,
            "createdAt": str,
            "description": str,
            "email": str,
            "externalId": str,
            "id": int,
            "label": str,
            "memberOf": [
                int
            ],
            "members": [
                {
                    "id": str,
                    "type": str
                }
            ],
            "membersCount": int,
            "name": str,
            "removed": bool,
            "type": str
        }

	"""

	url = f'https://api360.yandex.net/directory/v1/org/{orgID}/groups/{groupID}/admins'
	headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

	return safe_request('put', url, headers, json.dumps(body))

def delete_admins_group(token, orgID, groupID):
	"""Функция удаляет всех руководителей группы
	
    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param body: тело запроса
    :type body: dict
    :param ID: ID группы
    :type ID: str
    :return: :numref:`результат запроса %s <Результат запроса delete_admins_group>`
    :rtype: dict

    .. code-block:: python
        :caption: Результат запроса delete_admins_group
        :name: Результат запроса delete_admins_group

        {
            "adminIds": [
                str
            ],
            "aliases": [
                str
            ],
            "authorId": str,
            "createdAt": str,
            "description": str,
            "email": str,
            "externalId": str,
            "id": int,
            "label": str,
            "memberOf": [
                int
            ],
            "members": [
                {
                    "id": str,
                    "type": str
                }
            ],
            "membersCount": int,
            "name": str,
            "removed": bool,
            "type": str
        }

	"""

	url = f'https://api360.yandex.net/directory/v1/org/{orgID}/groups/{groupID}/admins'
	headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

	return safe_request('delete', url, headers)


"""Модуль позволяет управлять параметрами паролей пользователей организации.

.. note::
    **Разрешения на использование сервиса, которые доступны при настройке приложения:**

    **ya360_security:domain_passwords_read** — чтение информации о параметрах паролей пользователей;
    **ya360_security:domain_passwords_write** — управление параметрами паролей пользователей.


"""

from jreq.jreq import safe_request
import json

def show_domain_passwords(token, orgID):
    """Функция позволяет просмотреть параметры парольной политики в организации:

    Наличие у пользователей возможности самостоятельно менять пароль;
    Наличие и длительность (в днях) срока действия пароля.


    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :return: :numref:`результат запроса %s <Результат запроса show_domain_passwords>`
    :rtype: dict

    .. code-block:: python
        :caption: Результат запроса show_domain_passwords
        :name: Результат запроса show_domain_passwords

        {
            "changeFrequency": int,
            "enabled": bool
        }

    """

    url = f'https://api360.yandex.net/security/v1/org/{orgID}/domain_passwords'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}
	
    return safe_request('get', url, headers)

def edit_domain_passwords (token, orgID, body):
    """Функция позволяет управлять парольной политикой пользователей организации:

    разрешать или запрещать самостоятельную смену пароля;
    устанавливать периодичность смены пароля.


    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param body: :numref:`тело запроса %s <Тело запроса edit_domain_passwords>`
    :type body: dict
    :return: :numref:`результат запроса %s <Результат запроса edit_domain_passwords>`
    :rtype: dict


    .. code-block:: python
        :caption: Тело запроса edit_domain_passwords
        :name: Тело запроса edit_domain_passwords

        {
            "changeFrequency": int,
            "enabled": bool
        }

    .. code-block:: python
        :caption: Результат запроса edit_domain_passwords
        :name: Результат запроса edit_domain_passwords

        {
            "changeFrequency": int,
            "enabled": bool
        }

    """

    url = f'https://api360.yandex.net/security/v1/org/{orgID}/domain_passwords'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('put',url, headers, json.dumps(body))


"""Модуль функций для работы с настройками
почтовых ящиков сотрудников. Работает для пользователей,
аккаунты которых созданы на домене организации.

.. note::
    **Разрешения на использование сервиса, которые доступны при настройке приложения:**

    **ya360_admin:mail_read_user_settings** — чтение настроек почты пользователя;
    **ya360_admin:mail_write_user_settings** — управление настройками почты пользователя.


"""

from jreq.jreq import safe_request
import json

def show_sender_info (token, orgID, userID):
    """Функция позволяет просмотреть почтовый адрес, с которого отправляются письма по умолчанию, и настройки подписей сотрудника

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param userID: :term:`ID пользователя в Яндекс 360`
    :type userID: str
    :return: :numref:`результат запроса %s <Результат запроса show_sender_info>`
    :rtype: dict

    .. code-block:: python
        :caption: Результат запроса show_sender_info
        :name: Результат запроса show_sender_info

        {
            "defaultFrom": str,
            "fromName": str,
            "signPosition": str,
            "signs": [
                {
                    "emails": [
                        str
                    ],
                    "isDefault": bool,
                    "lang": str,
                    "text": str
                }
            ]
        }

    """

    url = f'https://api360.yandex.net/admin/v1/org/{orgID}/mail/users/{userID}/settings/sender_info'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('get',url, headers)

def edit_sender_info (token, orgID, userID, body):
    """Функция позволяет управлять почтовым адресом сотрудника, с которого отправляются письма по умолчанию, и настройками его подписей

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param userID: :term:`ID пользователя в Яндекс 360`
    :type userID: str
    :param body: :numref:`Тело запроса %s <Тело запроса edit_sender_info>`
    :type body: dict
    :return: :numref:`результат запроса %s <Результат запроса edit_sender_info>`
    :rtype: dict

    .. code-block:: python
        :caption: Тело запроса edit_sender_info
        :name: Тело запроса edit_sender_info

        {
            "defaultFrom": str,
            "fromName": str,
            "signPosition": str,
            "signs": [
                {
                    "emails": [
                        str
                    ],
                    "isDefault": bool,
                    "lang": str,
                    "text": str
                }
            ]
        }

    .. code-block:: python
        :caption: Результат запроса edit_sender_info
        :name: Результат запроса edit_sender_info

        {
            "defaultFrom": str,
            "fromName": str,
            "signPosition": str,
            "signs": [
                {
                    "emails": [
                        str
                    ],
                    "isDefault": bool,
                    "lang": str,
                    "text": str
                }
            ]
        }

    """

    url = f'https://api360.yandex.net/admin/v1/org/{orgID}/mail/users/{userID}/settings/sender_info'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('post',url, headers, json.dumps(body))

def show_user_rules (token, orgID, userID):
    """Функция позволяет просмотреть правила автоответа и пересылки писем

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param userID: :term:`ID пользователя в Яндекс 360`
    :type userID: str
    :return: :numref:`результат запроса %s <Результат запроса show_user_rules>`
    :rtype: dict

    .. code-block:: python
        :caption: Результат запроса show_user_rules
        :name: Результат запроса show_user_rules

        {
            "autoreplies": [
                {
                    "ruleId": integer,
                    "ruleName": string,
                    "text": string
                }
            ],
            "forwards": [
                {
                    "address": string,
                    "ruleId": integer,
                    "ruleName": string,
                    "withStore": boolean
                }
            ]
        }

    """

    url = f'https://api360.yandex.net/admin/v1/org/{orgID}/mail/users/{userID}/settings/user_rules'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('get',url, headers)

def edit_user_rules (token, orgID, userID, body):
    """Функция позволяет создать правило автоответа или пересылки писем для сотрудника.

    .. note::
        Возможность пересылки есть только на домены, которые принадлежат выбранной организации.
        Подтверждение получения пересылки при создании такого правила не требуется

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param userID: :term:`ID пользователя в Яндекс 360`
    :type userID: str
    :param body: :numref:`Тело запроса %s <Тело запроса edit_user_rules>`
    :type body: dict
    :return: :numref:`результат запроса %s <Результат запроса edit_user_rules>`
    :rtype: dict

    .. code-block:: python
        :caption: Тело запроса edit_user_rules
        :name: Тело запроса edit_user_rules

        {
            "autoreplies": [
                {
                    "ruleName": string,
                    "text": string
                }
            ],
            "forwards": [
                {
                    "address": string,
                    "ruleName": string,
                    "withStore": boolean
                }
            ]
        }

    .. code-block:: python
        :caption: Результат запроса edit_user_rules
        :name: Результат запроса edit_user_rules

        {
            "ruleId": int 
        }

    """

    url = f'https://api360.yandex.net/admin/v1/org/{orgID}/mail/users/{userID}/settings/user_rules'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('post',url, headers, json.dumps(body))

def delete_user_rules (token, orgID, userID, ruleID):
    """Функция удаляет конкретное правило автоответа или пересылки писем, настроенное для сотрудника

    .. danger::
        **Данная операция необратима, восстановить данные будет невозможно!**

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param userID: :term:`ID пользователя в Яндекс 360`
    :type userID: str
    :param ruleID: :term:`ID правила`
    :type ruleID: int
    :return: результат запроса: {}
    :rtype: dict

    """

    url = f'https://api360.yandex.net/admin/v1/org/{orgID}/mail/users/{userID}/settings/user_rules/{ruleID}'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('delete',url, headers)

def show_address_book (token, orgID, userID):
    """Функция позволяет просмотреть, включено ли автоматическое формирование адресной книги сотрудника из адресов исходящей почты

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param userID: :term:`ID пользователя в Яндекс 360`
    :type userID: str
    :return: :numref:`результат запроса %s <Результат запроса show_address_book>`
    :rtype: dict

    .. code-block:: python
        :caption: Результат запроса show_address_book
        :name: Результат запроса show_address_book

        {
            "collectAddresses": bool 
        }

    """

    url = f'https://api360.yandex.net/admin/v1/org/{orgID}/mail/users/{userID}/settings/address_book'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('get',url, headers)

def edit_address_book (token, orgID, userID, body):
    """Функция позволяет управлять опцией автоматического формирования адресной книги сотрудника из адресов исходящей почты

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param userID: :term:`ID пользователя в Яндекс 360`
    :type userID: str
    :param body: :numref:`Тело запроса %s <Тело запроса edit_address_book>`
    :type body: dict
    :return: :numref:`результат запроса %s <Результат запроса edit_address_book>`
    :rtype: dict

    .. code-block:: python
        :caption: Тело запроса edit_address_book
        :name: Тело запроса edit_address_book

        {
            "collectAddresses": bool 
        }

    .. code-block:: python
        :caption: Результат запроса edit_address_book
        :name: Результат запроса edit_address_book

        {
            "collectAddresses": bool 
        }

    """

    url = f'https://api360.yandex.net/admin/v1/org/{orgID}/mail/users/{userID}/settings/address_book'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('post',url, headers, json.dumps(body))


"""Инструмент для управления потоком входящих писем на уровне домена. Управление подразумевает создание специальных правил обработки писем для сотрудников организации, выполняется Администратором и определяет настройки имеющие приоритет над пользовательскими.

.. note::
    **Разрешения на использование сервиса, которые доступны при настройке приложения:**

    **ya360_admin:mail_write_routing_rules** — просмотр и изменения;
    **ya360_admin:mail_read_routing_rules** — просмотр.

"""

from jreq.jreq import safe_request
import json

def show_routing(token, orgID):
    '''Функция вывода содержимого таблицы правил обработки почты
    
    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :return: :numref:`результат запроса %s <Результат запроса show_routing>`
    :rtype: dict

    .. code-block:: python
        :caption: Результат запроса show_routing
        :name: Результат запроса show_routing

        {
            "rules": [
                {
                    "actions": [
                        {}
                    ],
                    "terminal": bool
                }
            ]
        }

    '''

    url = 'https://api360.yandex.net/admin/v1/org/'+orgID+'/mail/routing/rules'
    headers={'Authorization': 'OAuth '+token, 'Content-type': 'application/json'}

    return safe_request('get', url, headers)

def edit_routing(token, orgID, body):
    '''Функция изменения содержимого таблицы правил обработки почты
    
    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param body: :numref:`тело запроса %s <Тело запроса edit_routing>`
    :type body: dict
    :return: пустой словарь: {}
    :rtype: dict

    .. code-block:: python
        :caption: Тело запроса edit_routing
        :name: Тело запроса edit_routing

        {
            "rules": [
                {
                    "actions": [
                        {
                            "action": str,
                            "data": {
                                "email": str
                            }
                        }
                    ],
                    "terminal": bool
                }
            ]
        }

    '''

    url = 'https://api360.yandex.net/admin/v1/org/'+orgID+'/mail/routing/rules'
    headers={'Authorization': 'OAuth '+token, 'Content-type': 'application/json'}

    return safe_request('put', url, headers, json.dumps(body))
    



"""Модуль функций  для работы с доменами. Просмотр, создание, изменение и удаление. Получение статуса подключения и настроек доменов.

.. note::
    **Права доступа для работы с доменами:**

    **directory:read_domains**  — просмотр;
    **directory:write_domains** — просмотр и изменение.


"""

from jreq.jreq import safe_request
import json

def add_domain (token, orgID, domain):
    """Функция используется, чтобы подключить новый домен.

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param domain: Полное имя домена
    :type domain: str
    :return: :numref:`результат запроса %s <Результат запроса add_domain>`
    :rtype: dict

    .. code-block:: python
        :caption: Результат запроса add_domain
        :name: Результат запроса add_domain

        {
            "country": str,
            "delegated": bool,
            "master": bool,
            "mx": bool,
            "name": str,
            "status": {
                "dkim": {
                    "match": bool,
                    "value": str
                },
                "lastAdded": str,
                "lastCheck": str,
                "mx": {
                    "match": bool,
                    "value": str
                },
                "name": str,
                "ns": {
                    "match": bool,
                    "value": str
                },
                "spf": {
                    "match": bool,
                    "value": str
                }
            },
            "verified": bool
        }

    """

    body = {'domain':domain}
    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/domains'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('post',url, headers, json.dumps(body))

def show_domains(token, orgID, page=1, perPage=10):
    """Функция возвращает список доменов организации с постраничной навигацией

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param page: Номер страницы ответа. Значение по умолчанию — 1
    :type page: int
    :param perPage: Количество доменов на одной странице ответа. Значение по умолчанию — 10
    :type perPage: int
    :return: :numref:`результат запроса %s <Результат запроса show_domain>`
    :rtype: dict

    .. code-block:: python
        :caption: Результат запроса show_domain
        :name: Результат запроса show_domain

        {
            "domains": [
                {
                    "country": str,
                    "delegated": bool,
                    "master": bool,
                    "mx": bool,
                    "name": str,
                    "status": {
                        "dkim": {
                            "match": bool,
                            "value": str
                        },
                        "lastAdded": str,
                        "lastCheck": str,
                        "mx": {
                            "match": bool,
                            "value": str
                        },
                        "name": str,
                        "ns": {
                            "match": bool,
                            "value": str
                        },
                        "spf": {
                            "match": bool,
                            "value": str
                        }
                    },
                    "verified": bool
                }
            ],
            "page": int,
            "pages": int,
            "perPage": int,
            "total": int
        }

    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/domains/?page={page}&perPage={perPage}'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}
	
    return safe_request('get', url, headers)

def delete_domain (token, orgID, domain):
    """Функция позволяет удалить домен.

    .. note::
        Вы можете удалить любой домен, кроме технического.

    .. danger::
        **Данная операция необратима, восстановить данные будет невозможно!**

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param domain: Полное имя домена
    :type domain: str
    :return: http код
    :rtype: dict

    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/domains{domain}'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('delete',url, headers)

def status_domain (token, orgID, domain):
    """Проверяет статус подключения домена.

    .. note::
        Запрос позволяет получить результат последней проверки, дату и время ее выполнения, а также дату и время следующей проверки.

        **Для кириллических доменов (например домен.рф) используйте кодировку Punycode.**

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param domain: Полное имя домена
    :type domain: str
    :return: :numref:`результат запроса %s <Результат запроса status_domain>`
    :rtype: dict

    .. code-block:: python
        :caption: Результат запроса status_domain
        :name: Результат запроса status_domain

        {
            "methods": [
                {
                    "code": str,
                    "method": str
                }
            ],
            "status": str
        }

    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/domains/{domain}/status'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('get',url, headers)

def enable_domain_dkim (token, orgID, domain):
    """Включить DKIM подпись для домена

    .. note::
        **Для кириллических доменов (например домен.рф) используйте кодировку Punycode.**

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param domain: Полное имя домена
    :type domain: str
    :return: http код
    :rtype: dict

    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/domains/{domain}/dkim/enable'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('post',url, headers)

def disable_domain_dkim (token, orgID, domain):
    """Выключить DKIM подпись для домена

    .. note::
        **Для кириллических доменов (например домен.рф) используйте кодировку Punycode.**

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param domain: Полное имя домена
    :type domain: str
    :return: http код
    :rtype: dict

    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/domains/{domain}/dkim/disable'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('post',url, headers)

def status_domain_dkim (token, orgID, domain):
    """Получить статус DKIM подпись для домена

    .. note::
        **Для кириллических доменов (например домен.рф) используйте кодировку Punycode.**

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param domain: Полное имя домена
    :type domain: str
    :return: :numref:`результат запроса %s <Результат запроса status_domain_dkim>`
    :rtype: dict

    .. code-block:: python
        :caption: Результат запроса status_domain_dkim
        :name: Результат запроса status_domain_dkim

        {
            "enabled": bool,
            "publicKey": str
        }

    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/domains/{domain}/dkim/disable'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('post',url, headers)


# Configuration file for the Sphinx documentation builder.
#
# For the full list of built-in configuration values, see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Project information -----------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#project-information

import os
import sys
sys.path.insert(0, os.path.abspath('../..'))

master_doc = 'index'

project = 'Yandex 360 Lib'
copyright = '2024, Купцов Игорь Валерьевич'
author = 'Купцов Игорь Валерьевич'

html_extra_path = ['_static/robots.txt']
html_baseurl = 'https://yandex-360.readthedocs.io/'

# -- General configuration ---------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#general-configuration

extensions = [
    'sphinx.ext.duration',
    'sphinx.ext.autodoc',
    'sphinx_sitemap'
]

templates_path = ['_templates']
exclude_patterns = []

language = 'ru'

# -- Options for HTML output -------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#options-for-html-output

html_theme = 'sphinx_rtd_theme'
html_static_path = ['_static']
numfig = True


"""Модуль функций для просмотра организаций пользователя
"""

from jreq.jreq import safe_request
import json

def show_orgs(token, orgID, pageSize=10, pageToken=None):
    """Функция возвращает список организаций пользователя

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param pageSize: Количество организаций на странице. Максимальное значение — 100. По умолчанию — 10
    :type pageSize: int
    :param pageToken: Токен постраничной навигации
    :type pageToken: str
    :return: :numref:`результат запроса %s <Результат запроса show_orgs>`
    :rtype: dict

    .. code-block:: python
        :caption: Результат запроса show_orgs
        :name: Результат запроса show_orgs

        {
            "nextPageToken": str,
            "organizations": [
                {
                    "email": str,
                    "fax": str,
                    "id": int,
                    "language": str,
                    "name": str,
                    "phone": str,
                    "subscriptionPlan": str
                }
            ]
        }

    """

    url = f'https://api360.yandex.net/directory/v1/org?pageSize={pageSize}'
    if pageToken: url += f'&pageToken={pageToken}'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('get', url, headers)


"""Модуль функций для работы с подразделениями. Просмотр, создание, изменение и удаление.

.. note::
    **Права доступа для работы с подразделениями:**

    **directory:read_departments** — просмотр;
    **directory:write_departments** — просмотр и изменение.


"""

from jreq.jreq import safe_request
import json

def add_department(token, orgID, body):
    """Функция создания подразделения

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param body: :numref:`Тело запроса %s <Тело запроса add_department>`
    :type body: dict
    :return: :numref:`результат запроса %s <Результат запроса add_department>`
    :rtype: dict

    .. code-block:: python
        :caption: Тело запроса add_department
        :name: Тело запроса add_department

        {
            "description": str,
            "externalId": str,
            "headId": str,
            "label": str,
            "name": str,
            "parentId": int
        }

    .. code-block:: python
        :caption: Результат запроса add_department
        :name: Результат запроса add_department

        {
            "aliases": [
                str
            ],
            "createdAt": str,
            "description": str,
            "email": str,
            "externalId": str,
            "headId": str,
            "id": integer,
            "label": str,
            "membersCount": int,
            "name": str,
            "parentId": int
        }

    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/departments'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('post', url, headers, json.dumps(body))

def update_department(token, orgID, depID, body):
    """Функция изменяет информацию о подразделении.
    
    .. note::
        Изменяются значения только тех параметров, которые были переданы в запросе.

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param depID: :term:`ID подразделения в Яндекс 360`
    :type depID: str
    :param body: :numref:`Тело запроса %s <Тело запроса update_department>`
    :type body: dict
    :return: :numref:`результат запроса %s <Результат запроса update_department>`
    :rtype: dict

    .. code-block:: python
        :caption: Тело запроса update_department
        :name: Тело запроса update_department

        {
            "description": str,
            "externalId": str,
            "headId": str,
            "label": str,
            "name": str,
            "parentId": int
        }

    .. code-block:: python
        :caption: Результат запроса update_department
        :name: Результат запроса update_department

        {
            "aliases": [
                str
            ],
            "createdAt": str,
            "description": str,
            "email": str,
            "externalId": str,
            "headId": str,
            "id": integer,
            "label": str,
            "membersCount": int,
            "name": str,
            "parentId": int
        }

    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/departments/{depID}'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('patch', url, headers, json.dumps(body))

def delete_department(token, orgID, depID):
    """Функция удаляет подразделение.
    
    .. note::
        Запрос может быть выполнен только для подразделения без сотрудников и вложенных подразделений

    .. danger::
        **Данная операция необратима, восстановить данные будет невозможно!**

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param depID: :term:`ID подразделения в Яндекс 360`
    :type depID: str
    :return: :numref:`результат запроса %s <Результат запроса delete_department>`
    :rtype: dict

    .. code-block:: python
        :caption: Результат запроса delete_department
        :name: Результат запроса delete_department

        {
            "id": int,
            "removed": bool
        }

    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/departments/{depID}'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}
    
    return safe_request('delete', url, headers)

def add_alias_department(token, orgID, depID, body):
    """Функция добавляет подразделению алиас почтовой рассылки.
    
    .. note::
        Запрос может быть выполнен только для подразделений, у которых уже указано основное имя почтовой рассылки в поле **label**

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param depID: :term:`ID подразделения в Яндекс 360`
    :type depID: str
    :param body: :numref:`Тело запроса %s <Тело запроса add_alias_department>`
    :type body: dict
    :return: :numref:`результат запроса %s <Результат запроса add_alias_department>`
    :rtype: dict

    .. code-block:: python
        :caption: Тело запроса add_alias_department
        :name: Тело запроса add_alias_department

        {
            "alias": str
        }

    .. code-block:: python
        :caption: Результат запроса add_alias_department
        :name: Результат запроса add_alias_department

        {
            "aliases": [
                str
            ],
            "createdAt": str,
            "description": str,
            "email": str,
            "externalId": str,
            "headId": str,
            "id": integer,
            "label": str,
            "membersCount": int,
            "name": str,
            "parentId": int
        }

    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/departments/{depID}/aliases'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('post', url, headers, json.dumps(body))

def delete_alias_department(token, orgID, depID, alias):
    """Функция удаляет алиас почтовой рассылки подразделения

    .. danger::
        **Данная операция необратима, восстановить данные будет невозможно!**

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param depID: :term:`ID подразделения в Яндекс 360`
    :type depID: str
    :param alias: альяс
    :type alias: str
    :return: :numref:`результат запроса %s <Результат запроса delete_alias_department>`
    :rtype: dict

    .. code-block:: python
        :caption: Результат запроса delete_alias_department
        :name: Результат запроса delete_alias_department

        {
            "alias": str,
            "removed": bool
        }

    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/departments/{depID}/aliases/{alias}'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('delete', url, headers)

def show_department(token, orgID, depID):
    """Функция возвращает информацию об одном подразделении

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param depID: :term:`ID подразделения в Яндекс 360`
    :type depID: str
    :return: :numref:`результат запроса %s <Результат запроса show_department>`
    :rtype: dict

    .. code-block:: python
        :caption: Результат запроса show_department
        :name: Результат запроса show_department

        {
            "aliases": [
                str
            ],
            "createdAt": str,
            "description": str,
            "email": str,
            "externalId": str,
            "headId": str,
            "id": integer,
            "label": str,
            "membersCount": int,
            "name": str,
            "parentId": int
        }

    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/departments/{depID}'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('get', url, headers)

def show_departments(token, orgID, page=1, perPage=10, parentId=None, orderBy='id'):
    """Функция возвращает список подразделений с постраничной навигацией

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param page: Номер страницы ответа. Значение по умолчанию — 1
    :type page: int
    :param perPage: Количество подраздлений на одной странице ответа. Значение по умолчанию — 10
    :type perPage: int
    :param parentId: Идентификатор родительского подразделения. Если не указан, то выводятся все подразделения организации
    :type parentId: str
    :param orderBy: Вид сортировки. Возможные значения: 'id' или 'name'
    :type orderBy: str
    :return: :numref:`результат запроса %s <Результат запроса show_departments>`
    :rtype: dict

    .. code-block:: python
        :caption: Результат запроса show_departments
        :name: Результат запроса show_departments

        {
            "departments": [
                {
                    "aliases": [
                        str
                    ],
                    "createdAt": str,
                    "description": str,
                    "email": str,
                    "externalId": str,
                    "headId": str,
                    "id": int,
                    "label": str,
                    "membersCount": int,
                    "name": str,
                    "parentId": int
                }
            ],
            "page": int,
            "pages": int,
            "perPage": int,
            "total": int
        }

    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/departments/?page={page}&perPage={perPage}&orderBy={orderBy}'
    if parentId: url += f'&parentId={parentId}'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('get', url, headers)


"""Модуль для управления обязательной двухфакторной аутентификацией (2FA) пользователей домена.

.. note::
    **Разрешения на использование сервиса, которые доступны при настройке приложения:**

    **ya360_security:domain_2fa_write** — управление обязательной 2FA для пользователей.


"""

from jreq.jreq import safe_request
import json

def show_domain_2fa(token, orgID):
    """Функция Возвращает статус обязательной двухфакторной аутентификации (2FA) для пользователей домена.

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :return: :numref:`результат запроса %s <Результат запроса show_domain_2fa>`
    :rtype: dict

    .. code-block:: python
        :caption: Результат запроса show_domain_2fa
        :name: Результат запроса show_domain_2fa

        {
            "duration": int,
            "enabled": bool,
            "enabledAt": str
        }

    """

    url = f'https://api360.yandex.net/security/v1/org/{orgID}/domain_2fa'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}
	
    return safe_request('get', url, headers)

def enable_domain_2fa (token, orgID, body):
    """Функция включает обязательную двухфакторную аутентификацию (2FA) для пользователей домена.

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param body: :numref:`тело запроса %s <Тело запроса enable_domain_2fa>`
    :type body: dict
    :return: :numref:`результат запроса %s <Результат запроса enable_domain_2fa>`
    :rtype: dict


    .. code-block:: python
        :caption: Тело запроса enable_domain_2fa
        :name: Тело запроса enable_domain_2fa

        {
            "duration": int,
            "logoutUsers": bool,
            "validationMethod": str
        }

    .. code-block:: python
        :caption: Результат запроса enable_domain_2fa
        :name: Результат запроса enable_domain_2fa

        {
            "duration": int,
            "enabled": bool,
            "enabledAt": str
        }

    """

    url = f'https://api360.yandex.net/security/v1/org/{orgID}/domain_2fa'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('post',url, headers, json.dumps(body))

def disable_domain_2fa (token, orgID, body):
    """Функция включает обязательную двухфакторную аутентификацию (2FA) для пользователей домена.

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :return: :numref:`результат запроса %s <Результат запроса disable_domain_2fa>`
    :rtype: dict

    .. code-block:: python
        :caption: Результат запроса disable_domain_2fa
        :name: Результат запроса disable_domain_2fa

        {
            "duration": int,
            "enabled": bool,
            "enabledAt": str
        }

    """

    url = f'https://api360.yandex.net/security/v1/org/{orgID}/domain_2fa'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('delete',url, headers)


"""Модуль для работы с настройками антиспама.

.. note::
    **Разрешения на использование сервиса, которые доступны при настройке приложения:**

    **ya360_admin:mail_read_antispam_settings** — чтение настроек антиспама;
    **ya360_admin:mail_write_antispam_settings** — управление настройками антиспама (чтение и запись).


"""

from jreq.jreq import safe_request
import json

def show_whitelist(token, orgID):
    '''Функция вывода содержимого белого списка
    
    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :return: :numref:`результат запроса %s <Результат запроса show_whitelist>`
    :rtype: dict

    .. code-block:: python
        :caption: Результат запроса show_whitelist
        :name: Результат запроса show_whitelist

        {
            "allowList": [
                str
            ]
        }

    '''

    url = 'https://api360.yandex.net/admin/v1/org/'+orgID+'/mail/antispam/allowlist/ips'
    headers={'Authorization': 'OAuth '+token, 'Content-type': 'application/json'}

    return safe_request('get', url, headers)


def create_whitelist(token, orgID, body):
    '''Функция создания или замены содержимого белого списка
    
    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param body: :numref:`тело запроса %s <Тело запроса create_whitelist>`
    :type body: dict
    :return: результат запроса: {}
    :rtype: dict

    .. code-block:: python
        :caption: Тело запроса create_whitelist
        :name: Тело запроса create_whitelist

        {
            "allowList": [
                str
            ]
        }

    '''

    url = 'https://api360.yandex.net/admin/v1/org/'+orgID+'/mail/antispam/allowlist/ips'
    headers={'Authorization': 'OAuth '+token, 'Content-type': 'application/json'}

    return safe_request('post', url, headers, json.dumps(body))


def delete_whitelist(token, orgID):
    '''Функция удаления содержимого белого списка
    
    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :return: результат запроса: {}
    :rtype: dict

    '''

    url = 'https://api360.yandex.net/admin/v1/org/'+orgID+'/mail/antispam/allowlist/ips'
    headers={'Authorization': 'OAuth '+token, 'Content-type': 'application/json'}

    return safe_request('delete', url, headers)




"""Модуль для управления временем жизни cookie сессий пользователей. Позволяет выйти из аккаунта пользователя на всех устройствах.

.. note::
    **Разрешения на использование сервиса, которые доступны при настройке приложения:**

    **ya360_security:domain_sessions_read** — чтение информации о времени жизни cookie сессий пользователей;
    **ya360_security:domain_sessions_write** — управление временем жизни cookie сессий пользователей и авторизацией.


"""

from jreq.jreq import safe_request
import json

def show_domain_sessions(token, orgID):
    """Функция возвращает время жизни cookie сессий пользователей организации.
    Значение по умолчанию — 0. Это значит, что время жизни cookie сессий не ограничено.

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :return: :numref:`результат запроса %s <Результат запроса show_domain_sessions>`
    :rtype: dict

    .. code-block:: python
        :caption: Результат запроса show_domain_sessions
        :name: Результат запроса show_domain_sessions

        {
            "authTTL": int
        }

    """

    url = f'https://api360.yandex.net/security/v1/org/{orgID}/domain_sessions'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}
	
    return safe_request('get', url, headers)

def edit_domain_sessions (token, orgID, body):
    """Функция позволяет возможность поменять время жизни cookie сессий пользователей организации.

    .. warning::
        Ограничение. Чтобы выполнить запрос, приложению требуется разрешение на управление временем жизни cookie сессий пользователей и авторизацией.


    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param body: :numref:`тело запроса %s <Тело запроса edit_domain_sessions>`
    :type body: dict
    :return: :numref:`результат запроса %s <Результат запроса edit_domain_sessions>`
    :rtype: dict


    .. code-block:: python
        :caption: Тело запроса edit_domain_sessions
        :name: Тело запроса edit_domain_sessions

        {
            "authTTL": int
        }

    .. code-block:: python
        :caption: Результат запроса edit_domain_sessions
        :name: Результат запроса edit_domain_sessions

        {
            "authTTL": int
        }

    """

    url = f'https://api360.yandex.net/security/v1/org/{orgID}/domain_sessions'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('post',url, headers, json.dumps(body))

def close_domain_sessions(token, orgID, userID):
    """Функция позволяет выйти из аккаунта определенного пользователя на всех устройствах, где произведен вход.

    .. danger::
        **Данная функция удаляет все пароли приложений!**

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param userID: :term:`ID пользователя в Яндекс 360`
    :type userID: str
    :return: результат запроса: {}
    :rtype: dict



    """

    url = f'https://api360.yandex.net/security/v1/org/{orgID}/domain_sessions/users/{userID}/logout'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}
	
    return safe_request('put', url, headers)


"""Модуль функций для работы с сотрудниками. Просмотр, создание, изменение и удаление.

.. note::
    **Права доступа для работы с данными сотрудников:**

    **directory:read_users** — просмотр;
    
    **directory:write_users** — просмотр и изменение.


"""

from jreq.jreq import safe_request
import json

def show_users(token, orgID, page=1, perPage=10):
    """Функция Возвращает список сотрудников с постраничной навигацией

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param page: Номер страницы ответа. Значение по умолчанию — 1
    :type page: int
    :param perPage: Количество пользователей на одной странице ответа. Значение по умолчанию — 10
    :type perPage: int
    :return: :numref:`результат запроса %s <Результат запроса show_users>`
    :rtype: dict

    .. code-block:: python
        :caption: Результат запроса show_users
        :name: Результат запроса show_users

        {
            "page": int,
            "pages": int,
            "perPage": int,
            "total": int,
            "users": [
                {
                    "about": str,
                    "aliases": [
                        str
                    ],
                    "avatarId": str,
                    "birthday": str,
                    "contacts": [
                        {
                            "alias": bool,
                            "label": str,
                            "main": bool,
                            "synthetic": bool,
                            "type": str,
                            "value": str
                        }
                    ],
                    "createdAt": str,
                    "departmentId": int,
                    "displayName": str,
                    "email": str,
                    "externalId": str,
                    "gender": str,
                    "groups": [
                        int
                    ],
                    "id": str,
                    "isAdmin": bool,
                    "isDismissed": bool,
                    "isEnabled": bool,
                    "isRobot": bool,
                    "language": str,
                    "name": {
                        "first": str,
                        "last": str,
                        "middle": str
                    },
                    "nickname": str,
                    "position": str,
                    "timezone": str,
                    "updatedAt": str
                }
            ]
        }

    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/users/?page={page}&perPage={perPage}'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}
	
    return safe_request('get', url, headers)

def show_user(token, orgID, userID):
    """Функция возвращает информацию об одном сотруднике

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param userID: :term:`ID пользователя в Яндекс 360`
    :type userID: str
    :return: :numref:`результат запроса %s <Результат запроса show_user>`
    :rtype: dict

    .. code-block:: python
        :caption: Результат запроса show_user
        :name: Результат запроса show_user

        {
            "about": str,
            "aliases": [
                str
            ],
            "avatarId": str,
            "birthday": str,
            "contacts": [
                {
                    "alias": bool,
                    "label": str,
                    "main": bool,
                    "synthetic": bool,
                    "type": str,
                    "value": str
                }
            ],
            "createdAt": str,
            "departmentId": int,
            "displayName": str,
            "email": str,
            "externalId": str,
            "gender": str,
            "groups": [
                int
            ],
            "id": str,
            "isAdmin": bool,
            "isDismissed": bool,
            "isEnabled": bool,
            "isRobot": bool,
            "language": str,
            "name": {
                "first": str,
                "last": str,
                "middle": str
            },
            "nickname": str,
            "position": str,
            "timezone": str,
            "updatedAt": str
        }

    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/users/{userID}'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('get', url, headers)

def update_user(token, orgID, userID, body):
    """Функция изменяет информацию о сотруднике.

    .. note::
        Изменяются значения только тех параметров, которые были переданы в запросе.

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param userID: :term:`ID пользователя в Яндекс 360`
    :type userID: str
    :param body: :numref:`Тело запроса %s <Тело запроса update_user>`
    :type body: dict
    :return: :numref:`результат запроса %s <Результат запроса update_user>`
    :rtype: dict

    .. code-block:: python
        :caption: Тело запроса update_user
        :name: Тело запроса update_user

        {
            "about": str,
            "birthday": str,
            "contacts": [
                {
                    "label": str,
                    "type": str,
                    "value": str
                }
            ],
            "departmentId": int,
            "displayName": str,
            "externalId": str,
            "gender": str,
            "isAdmin": bool,
            "isEnabled": bool,
            "language": str,
            "name": {
                "first": str,
                "last": str,
                "middle": str
            },
            "password": str,
            "passwordChangeRequired": bool,
            "position": str,
            "timezone": str
        }

    .. code-block:: python
        :caption: Результат запроса update_user
        :name: Результат запроса update_user

        {
            "about": str,
            "aliases": [
                str
            ],
            "avatarId": str,
            "birthday": str,
            "contacts": [
                {
                    "alias": bool,
                    "label": str,
                    "main": bool,
                    "synthetic": bool,
                    "type": str,
                    "value": str
                }
            ],
            "createdAt": str,
            "departmentId": int,
            "displayName": str,
            "email": str,
            "externalId": str,
            "gender": str,
            "groups": [
                int
            ],
            "id": str,
            "isAdmin": bool,
            "isDismissed": bool,
            "isEnabled": bool,
            "isRobot": bool,
            "language": str,
            "name": {
                "first": str,
                "last": str,
                "middle": str
            },
            "nickname": str,
            "position": str,
            "timezone": str,
            "updatedAt": str
        }

    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/users/{userID}'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}
	
    return safe_request('patch', url, headers, json.dumps(body))

def add_user(token, orgID, body):
    """Функция добавляет нового сотрудника

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param body: :numref:`Тело запроса %s <Тело запроса add_user>`
    :type body: dict
    :return: :numref:`результат запроса %s <Результат запроса add_user>`
    :rtype: dict

    .. code-block:: python
        :caption: Тело запроса add_user
        :name: Тело запроса add_user

        {
            "about": str,
            "birthday": str,
            "contacts": [
                {
                    "label": str,
                    "type": str,
                    "value": str
                }
            ],
            "departmentId": int,
            "displayName": str,
            "externalId": str,
            "gender": str,
            "isAdmin": bool,
            "isEnabled": bool,
            "language": str,
            "name": {
                "first": str,
                "last": str,
                "middle": str
            },
            "nickname": str,
            "password": str,
            "passwordChangeRequired": bool,
            "position": str,
            "timezone": str
        }

    .. code-block:: python
        :caption: Результат запроса add_user
        :name: Результат запроса add_user

        {
            "about": str,
            "aliases": [
                str
            ],
            "avatarId": str,
            "birthday": str,
            "contacts": [
                {
                    "alias": bool,
                    "label": str,
                    "main": bool,
                    "synthetic": bool,
                    "type": str,
                    "value": str
                }
            ],
            "createdAt": str,
            "departmentId": int,
            "displayName": str,
            "email": str,
            "externalId": str,
            "gender": str,
            "groups": [
                int
            ],
            "id": str,
            "isAdmin": bool,
            "isDismissed": bool,
            "isEnabled": bool,
            "isRobot": bool,
            "language": str,
            "name": {
                "first": str,
                "last": str,
                "middle": str
            },
            "nickname": str,
            "position": str,
            "timezone": str,
            "updatedAt": str
        }

    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/users'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}
	
    return safe_request('post', url, headers, json.dumps(body))

def delete_user(token, orgID, userID):
    """Функция удаления пользователя

    .. danger::
        **Данная операция необратима, восстановить данные будет невозможно!**
        
        Будут удалены все почтовые сообщения, а также папки и файлы на Яндекс Диске

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param userID: :term:`ID пользователя в Яндекс 360`
    :type userID: str
    :return: результат запроса
    :rtype: dict

    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/users/{userID}'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('delete', url, headers)

def add_alias_user(token, orgID, userID, body):
    """Функция добавляет сотруднику алиас почтового ящика

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param userID: :term:`ID пользователя в Яндекс 360`
    :type userID: str
    :param body: :numref:`Тело запроса %s <Тело запроса add_alias_user>`
    :type body: dict
    :return: :numref:`результат запроса %s <Результат запроса add_alias_user>`
    :rtype: dict

    .. code-block:: python
        :caption: Тело запроса add_alias_user
        :name: Тело запроса add_alias_user

        {
            "alias": str,
        }

    .. code-block:: python
        :caption: Результат запроса add_alias_user
        :name: Результат запроса add_alias_user

        {
            "about": str,
            "aliases": [
                str
            ],
            "avatarId": str,
            "birthday": str,
            "contacts": [
                {
                    "alias": bool,
                    "label": str,
                    "main": bool,
                    "synthetic": bool,
                    "type": str,
                    "value": str
                }
            ],
            "createdAt": str,
            "departmentId": int,
            "displayName": str,
            "email": str,
            "externalId": str,
            "gender": str,
            "groups": [
                int
            ],
            "id": str,
            "isAdmin": bool,
            "isDismissed": bool,
            "isEnabled": bool,
            "isRobot": bool,
            "language": str,
            "name": {
                "first": str,
                "last": str,
                "middle": str
            },
            "nickname": str,
            "position": str,
            "timezone": str,
            "updatedAt": str
        }

    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/users/{userID}/aliases'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('post', url, headers, json.dumps(body))

def delete_alias_user(token, orgID, userID, alias):
    """Функция удаляет у сотрудника алиас почтового ящика

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param userID: :term:`ID пользователя в Яндекс 360`
    :type userID: str
    :param alias: альяс
    :type alias: str
    :return: :numref:`результат запроса %s <Результат запроса delete_alias_user>`
    :rtype: dict

    .. code-block:: python
        :caption: Результат запроса delete_alias_user
        :name: Результат запроса delete_alias_user

        {
            "alias": str,
            "removed": bool
        }

    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/users/{userID}/aliases/{alias}'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('delete', url, headers)

def update_user_contacts(token, orgID, userID, body):
    """Функция изменяет контактную информацию сотрудника.

    .. note::
        Автоматически созданную контактную информацию (с флагом synthetic) нельзя изменить или удалить

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param userID: :term:`ID пользователя в Яндекс 360`
    :type userID: str
    :param body: :numref:`Тело запроса %s <Тело запроса update_user_contacts>`
    :type body: dict
    :return: :numref:`результат запроса %s <Результат запроса update_user_contacts>`
    :rtype: dict

    .. code-block:: python
        :caption: Тело запроса update_user_contacts
        :name: Тело запроса update_user_contacts

        {
            "contacts": [
                {
                    "label": str,
                    "type": str,
                    "value": str
                }
            ]
        }

    .. code-block:: python
        :caption: Результат запроса update_user_contacts
        :name: Результат запроса update_user_contacts

        {
            "about": str,
            "aliases": [
                str
            ],
            "avatarId": str,
            "birthday": str,
            "contacts": [
                {
                    "alias": bool,
                    "label": str,
                    "main": bool,
                    "synthetic": bool,
                    "type": str,
                    "value": str
                }
            ],
            "createdAt": str,
            "departmentId": int,
            "displayName": str,
            "email": str,
            "externalId": str,
            "gender": str,
            "groups": [
                int
            ],
            "id": str,
            "isAdmin": bool,
            "isDismissed": bool,
            "isEnabled": bool,
            "isRobot": bool,
            "language": str,
            "name": {
                "first": str,
                "last": str,
                "middle": str
            },
            "nickname": str,
            "position": str,
            "timezone": str,
            "updatedAt": str
        }

    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/users/{userID}/contacts'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('put', url, headers, json.dumps(body))

def delete_user_contacts(token, orgID, userID):
    """Функция удаляет контактную информацию сотрудника внесенную вручную

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param userID: :term:`ID пользователя в Яндекс 360`
    :type userID: str
    :return: :numref:`результат запроса %s <Результат запроса delete_user_contacts>`
    :rtype: dict

    .. code-block:: python
        :caption: Результат запроса delete_user_contacts
        :name: Результат запроса delete_user_contacts

        {
            "about": str,
            "aliases": [
                str
            ],
            "avatarId": str,
            "birthday": str,
            "contacts": [
                {
                    "alias": bool,
                    "label": str,
                    "main": bool,
                    "synthetic": bool,
                    "type": str,
                    "value": str
                }
            ],
            "createdAt": str,
            "departmentId": int,
            "displayName": str,
            "email": str,
            "externalId": str,
            "gender": str,
            "groups": [
                int
            ],
            "id": str,
            "isAdmin": bool,
            "isDismissed": bool,
            "isEnabled": bool,
            "isRobot": bool,
            "language": str,
            "name": {
                "first": str,
                "last": str,
                "middle": str
            },
            "nickname": str,
            "position": str,
            "timezone": str,
            "updatedAt": str
        }

    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/users/{userID}/contacts'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('delete', url, headers)


def show_user_2fa(token, orgID, userID):
    """Функция возвращает информацию о статусе 2FA сотрудника

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param userID: :term:`ID пользователя в Яндекс 360`
    :type userID: str
    :return: :numref:`результат запроса %s <Результат запроса show_user_2fa>`
    :rtype: dict

    .. code-block:: python
        :caption: Результат запроса show_user_2fa
        :name: Результат запроса show_user_2fa

        {
            "has2fa": bool,
            "userId": str
        }

    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/users/{userID}/2fa'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('get', url, headers)

def delete_user_2fa(token, orgID, userID):
    """Функция сбрасывает телефон для 2FA у пользователя организации

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param userID: :term:`ID пользователя в Яндекс 360`
    :type userID: str
    :return: результат запроса: {}
    :rtype: dict

    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/users/{userID}/2fa'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'application/json'}

    return safe_request('delete', url, headers)

def upload_user_avatar(token, orgID, userID, avatar):
    """Функция управляет потретами пользователей организации.
    
    .. note::
        Работает только для пользователей, созданных на домене организации

    :param token: :term:`Яндекс токен приложения`
    :type token: str
    :param orgID: :term:`ID организации в Яндекс 360`
    :type orgID: str
    :param userID: :term:`ID пользователя в Яндекс 360`
    :type userID: str
    :param avatar: данные картинки в binary 
    :type avatar: binary
    :return: :numref:`результат запроса %s <Результат запроса upload_user_avatar>`
    :rtype: dict

    .. code-block:: python
        :caption: Результат запроса upload_user_avatar
        :name: Результат запроса upload_user_avatar

        {
            "url": str
        }

    """

    url = f'https://api360.yandex.net/directory/v1/org/{orgID}/users/{userID}/avatar'
    headers={'Authorization': f'OAuth {token}', 'Content-type': 'image/png'}

    return safe_request('put', url, headers, avatar)


"""Библиотека Yandex 360 API

.. moduleauthor:: Купцов Игорь Валерьевич <ya360@uh.net.ru>

"""

try:
    from ._version import __version__
except:
    __version__ = 'dev'

__author__ = 'Купцов Игорь Валерьевич'
